@@ -85,20 +85,72 @@ struct _GrlMediaImage
   gpointer _grl_reserved[GRL_PADDING_SMALL];
 };
 
-void grl_media_image_set_width (GrlMediaImage *data, gint width);
+void grl_media_image_set_width (GrlMediaImage *image, gint width);
 
-void grl_media_image_set_height (GrlMediaImage *data, gint height);
+void grl_media_image_set_height (GrlMediaImage *image, gint height);
 
-gint grl_media_image_get_width (GrlMediaImage *data);
+gint grl_media_image_get_width (GrlMediaImage *image);
+
+gint grl_media_image_get_height (GrlMediaImage *image);
+
+const gchar *grl_media_image_get_camera_model (GrlMediaImage *image);
+
+const gchar *grl_media_image_get_flash_used (GrlMediaImage *image);
+
+gfloat grl_media_image_get_exposure_time (GrlMediaImage *image);
+
+gfloat grl_media_image_get_iso_speed (GrlMediaImage *image);
+
+gint grl_media_image_get_orientation (GrlMediaImage *image);
 
-gint grl_media_image_get_height (GrlMediaImage *data);
 
-GType grl_media_image_get_type (void) G_GNUC_CONST;
-GrlMedia *grl_media_image_new (void);
 void grl_media_image_set_size (GrlMediaImage *image,
                                gint width,
                                gint height);
 
+const gchar *grl_media_image_get_url_data (GrlMediaImage *image,
+                                           gchar **mime,
+                                           gint *width,
+                                           gint *height);
+
+const gchar *grl_media_image_get_url_data_nth (GrlMediaImage *image,
+                                               guint index,
+                                               gchar **mime,
+                                               gint *width,
+                                               gint *height);
+
+void grl_media_image_set_url_data (GrlMediaImage *image,
+                                   const gchar *url,
+                                   const gchar *mime,
+                                   gint width,
+                                   gint height);
+
+void grl_media_image_add_url_data (GrlMediaImage *image,
+                                   const gchar *url,
+                                   const gchar *mime,
+                                   gint width,
+                                   gint height);
+
+void grl_media_image_set_camera_model (GrlMediaImage *image,
+                                       const gchar *camera_model);
+
+void grl_media_image_set_flash_used (GrlMediaImage *image,
+                                     const gchar *flash_used);
+
+void grl_media_image_set_exposure_time (GrlMediaImage *image,
+                                        gfloat exposure_time);
+
+void grl_media_image_set_iso_speed (GrlMediaImage *image,
+                                    gfloat iso_speed);
+
+void grl_media_image_set_orientation (GrlMediaImage *image,
+                                      gint orientation);
+
+GType grl_media_image_get_type (void) G_GNUC_CONST;
+
+GrlMedia *grl_media_image_new (void);
+
+
 G_END_DECLS
 
 #endif /* _GRL_MEDIA_IMAGE_H_ */
